Name: ipmiutil
Version: 2.4.0
Release: 1
Summary: A package that includes various IPMI server management utilities
License: BSD
Group: System Environment/Kernel
Source: http://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.gz
URL: http://ipmiutil.sourceforge.net
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root
%ifarch x86_pentium3 x86_pentium4
AutoReqProv: No
%define ManDir   /usr/share/man
%define InitDir  /etc/init.d
%else
%define ManDir   %{_mandir}
%define InitDir  %{_initrddir}
%endif
# ifarch x86_64, %_libdir will be /usr/lib64 
%define LibDir   %{_libdir}
%define DataDir  %{_datadir}/%{name}
%define ExtraDir %{_datadir}/%{name}
%define DevDir   /dev
%define DevNull  /dev/null
%define CronDir  /etc/cron.daily

%description
The ipmiutil component package provides utilities to view the SEL (showsel), 
perform a hardware reset (hwreset), set up the BMC LAN and Platform 
Event Filter entry to allow SNMP alerts (pefconfig), and other IPMI tasks.  
These can be invoked with the metacommand, ipmiutil, as well.  Man pages
are provided.
An IPMI driver can be provided by either the Intel IPMI driver (/dev/imb) 
or the OpenIPMI driver (/dev/ipmi0), etc.  If used locally and no driver is
detected, ipmiutil will use user-space direct I/Os instead.


%prep
%setup -q

%build
sh configure
make

%install
# Use %{buildroot} macro instead of $RPM_BUILD_ROOT now.
# %{buildroot} is set above in the header so it will never be "/"
# if [ "%{buildroot}" != "/" ]
rm -rf %{buildroot}
make install DESTDIR=%{buildroot}
( cd %{buildroot}%{ManDir}/man8; gzip -f *.8 ) 
rm -f %{buildroot}%{_sbindir}/xmlconfig 2>%{DevNull}
rm -f %{buildroot}%{LibDir}/libipmi_lanplus.*

%files
%defattr(0755,root,root)
%{_sbindir}/ipmiutil
%{_sbindir}/alarms
%{_sbindir}/bmchealth
%{_sbindir}/bmcconfig
%{_sbindir}/fruconfig
%{_sbindir}/getevent
%{_sbindir}/hwreset
%{_sbindir}/icmd
%{_sbindir}/pefconfig
%{_sbindir}/showsel
%{_sbindir}/sensor
%{_sbindir}/tmconfig
%{_sbindir}/wdt
%{_sbindir}/isolconsole
%{_sbindir}/idiscover
%{_sbindir}/ievents
%{_sbindir}/ipmi_port
%{InitDir}/ipmiutil_wdt
%{InitDir}/ipmiutil_asy
%{InitDir}/ipmi_port
%{CronDir}/checksel
%{DataDir}/ipmi_if.sh
# %{LibDir}/libipmi_lanplus.*
%defattr(0664,root,root)
%{DataDir}/README
%{DataDir}/COPYING
%{DataDir}/UserGuide
%{DataDir}/bmclanpet.mib
%{DataDir}/bmclanaol.mib
%{ManDir}/man8/showsel.8.gz
%{ManDir}/man8/sensor.8.gz
%{ManDir}/man8/hwreset.8.gz
%{ManDir}/man8/getevent.8.gz
%{ManDir}/man8/bmchealth.8.gz
%{ManDir}/man8/bmcconfig.8.gz
%{ManDir}/man8/alarms.8.gz
%{ManDir}/man8/wdt.8.gz
%{ManDir}/man8/pefconfig.8.gz
%{ManDir}/man8/tmconfig.8.gz
%{ManDir}/man8/fruconfig.8.gz
%{ManDir}/man8/icmd.8.gz
%{ManDir}/man8/ipmiutil.8.gz
%{ManDir}/man8/isolconsole.8.gz
%{ManDir}/man8/idiscover.8.gz
%{ManDir}/man8/ievents.8.gz
# %defattr(-,root,root)
# %doc README TODO COPYING ChangeLog

%clean
# %{buildroot} is set above in the header so it will never be "/"
# if [ "%{buildroot}" != "/" ]
rm -rf %{buildroot}

%pre
# before install
datadir=%{DataDir}
echo "Installing IPMI Management Utilities %{version} ..."
mkdir -p $datadir

dev1=%{DevDir}/imb
dev2=%{DevDir}/ipmi0
dev3=%{DevDir}/ipmi/0
dev4=%{DevDir}/ipmikcs
if [ ! -c $dev1 ]
then
  if [ ! -c $dev2 ]
  then
     if [ ! -c $dev3 ]
     then
        # No IPMI drivers detected.
        # The use of the driverless interface is not advisable on 
        # a multi-user OS.  
        echo "Warning: No IPMI drivers found ($dev1, $dev2, or $dev3)."
     fi
  fi
fi

# Some Linux distros still have /usr/man instead of /usr/share/man 
# Those distros should have %{ManDir} set to /usr/man. 

%post
# after install
pdir=%{_sbindir}
datadir=%{DataDir}
tmpdir=$(/bin/mktemp -d /tmp/ipmiutil.XXXXXX) || return 1
tmped=${tmpdir}/edmk.tmp
tmplan=${tmpdir}/pefcfg.tmp
mibdir=%{_datadir}/snmp/mibs
initdir=%{InitDir}

echo "ipmiutil-%{version} install started `date`" 

# If SuSE, check location of snmpd.conf for pefconfig
if [ -f /etc/SuSE-release ]
then
   if [ ! -f /etc/snmp/snmpd.conf ]
   then
     if [ -f /etc/ucdsnmpd.conf ]
     then
        mkdir -p /etc/snmp
        cd /etc/snmp
        ln -s /etc/ucdsnmpd.conf  snmpd.conf
     fi
     if [ -f /etc/snmpd.conf ]
     then
        mkdir -p /etc/snmp
        cd /etc/snmp
        ln -s /etc/snmpd.conf  snmpd.conf
     fi
   fi
fi
if [ -d $mibdir ]
then
   cp -f $datadir/bmclanpet.mib $mibdir/BMCLAN-PET-MIB.txt
   # cp -f $datadir/bmclanaol.mib $mibdir/BMCLAN-AOL-MIB.txt 
fi

newcrypto=%{LibDir}/libcrypto.so.4
if [ -f /etc/mvl-release ]
then
   # link libcrypto.4 on MontaVista, for safety
   if [ ! -f $newcrypto ] 
   then
      cp -f %{LibDir}/libcrypto.so.0 $newcrypto
   fi
fi

# check if chroot, if so, will not have /proc instances
if [ -f /proc/devices ]
then
   isroot=1
else
   isroot=0
fi

# If we installed shared library libipmi_lanplus.so, run ldconfig.
# ldconfig

# arg1 = 1 if rpm -i (first time), arg1 = 2 if rpm -U
if [ "$1" = "1" ]
then
  # doing rpm -i, first time

  # There can be any one of several IPMI driver modules installed.
  # Dont need to load a kernel module here. 
  
  # Check the Panic Timeout value for the OS Critical Stop event
  #if [ $isroot -eq 1 ]
  #then
  #  pfil=/proc/sys/kernel/panic
  #  pval=`cat $pfil`
  #  pnew=5
  #fi
  # How to set the Panic Timeout to 5 seconds:
  # If lilo, add 'append="panic=5"' to /etc/lilo.conf.
  # If grub, add 'panic=5' to the kernel line in /boot/grub/grub.conf.

  # Dont link to new command names, skip command symlinks

  # For any system, set up the checksel cron job for showsel
  # This is inert if IPMI is not supported.
  # cp $datadir/checksel %{CronDir}

  if [ $isroot -eq 1 ]
  then
     # detects IPMI interface type, output to $datadir/ipmi_if.txt
     $datadir/ipmi_if.sh 

     if [ -x $pdir/ipmiutil ]
     then 
        $pdir/ipmiutil wdt >%{DevNull} 2>&1
        fIPMI=$?
     else
        fIPMI=1
     fi
  else
     # assume IPMI is not supported
     fIPMI=1
  fi

  # If fIPMI==0, IPMI is supported, and not chroot.
  if [ $fIPMI -eq 0 ] 
  then
     #cp $datadir/wdt.sh $initdir/ipmiutil_wdt
     #cp $datadir/asy.sh $initdir/ipmiutil_asy
     #cp $datadir/ipmi_port.sh $initdir/ipmi_port
     # Reserve the IPMI RMCP port from the portmap service
     which chkconfig  >%{DevNull} 2>&1
     if [ $? -eq 0 ]
     then
        chkconfig --add ipmi_port
     fi

     # Set up first-time IPMI sensor and LAN functions
     sensorout=$datadir/sensor_out.txt
     if [ ! -f $sensorout ] 
     then
        # Now take a snapshot of the sensors on this system
        echo "Saving a sensor snapshot to $sensorout ..."
        $pdir/ipmiutil sensor >$sensorout
     fi

     # Check if the BMC LAN is already configured.
     $pdir/ipmiutil lan -t >%{DevNull}
     if [ $? -ne 0 ] 
     then
        # $? = 1, 2, or 3 means not fully configured.
        # not already configured
        # Read the BMC LAN configuration (saving BMC MAC, if any)
        $pdir/ipmiutil lan -r >$tmplan 2>&1
        # Some users may not want to auto-enable BMC LAN, and some
        # systems will require -I to be specified, so don't always
        # do this, just display a message.
        echo "The BMC LAN is not yet fully configured."
        echo "Use 'ipmiutil lan -e -I <ip>' or 'ipmiutil lan -e' to do this."
     fi
  fi
fi

echo "done `date`" 

%preun
# before uninstall
echo "Uninstalling ipmiutil-%{version} package ..."

# arg1 = 1 if rpm -U, arg1 = 0 if rpm -e
if [ "$1" = "0" ]
then
  if [ -x $initdir/ipmi_port ]
  then
     which chkconfig  >%{DevNull} 2>&1
     if [ $? -eq 0 ]
     then
        chkconfig --del ipmi_port
        chkconfig --del ipmiutil_wdt 2>%{DevNull}
        chkconfig --del ipmiutil_asy 2>%{DevNull}
     fi
  fi
fi

%postun
# after uninstall
pdir=%{_sbindir}
datadir=%{DataDir}
mibdir=%{_datadir}/snmp/mibs
tmpdir=$(/bin/mktemp -d /tmp/ipmiutil.XXXXXX) || return 1
tmped=${tmpdir}/edmk.tmp
initdir=%{InitDir}

# ldconfig

# arg1 = 1 if rpm -U, arg1 = 0 if rpm -e
if [ "$1" = "0" ]
then
  # doing rpm -e postun, so clean up anything left over
  rm -rf $datadir  2>%{DevNull}

  #if [ -f %{CronDir}/checksel ]
  #then
  #   rm -f %{CronDir}/checksel 2>%{DevNull}
  #fi

  # skip the new command symlinks 

  if [ -d $mibdir ]
  then
     rm -f $mibdir/BMCLAN-AOL-MIB.txt 2>%{DevNull}
     rm -f $mibdir/BMCLAN-PET-MIB.txt 2>%{DevNull}
  fi

fi

%changelog
* Tue Jun 23 2009 Andrew Cress <arcress@users.sourceforge.net> 2.4.0
  moved all progs to sbin, install init/cron scripts via %files not %post
* Wed Dec 10 2008 Andrew Cress <arcress@users.sourceforge.net> 2.3.2-1
  changes for Fedora with ipmiutil-2.3.2
* Fri Jun 08 2007 Andrew Cress <arcress@users.sourceforge.net>
  rpmlint tweaks for ipmiutil-1.9.8
* Mon May 21 2007 Andrew Cress <arcress@users.sourceforge.net>
  added isroot flag for chroot cases
* Mon May 18 2007 Andrew Cress <arcress@users.sourceforge.net>
  added ipmi_port init handling
* Mon Jul 10 2006 Andrew Cress <arcress@users.sourceforge.net>
  changed to libfreeipmi.so.2, include & run ipmi_if.sh
* Tue Aug 02 2005 Andrew Cress <arcress@users.sourceforge.net> 
  changed not to run pefconfig if already configured
* Wed Feb 03 2005 Andrew Cress <arcress@users.sourceforge.net> 
  changed /usr/man to /usr/share/man,
  fixed postun to recognize rpm -U via $1 
* Mon Nov 1 2004 Andrew Cress <arcress@users.sourceforge.net> 
  added freeipmi install files and logic
* Tue Aug 23 2004 Andrew Cress <arcress@users.sourceforge.net> 
- added MIB links to /usr/share/snmp/mibs
* Tue Aug 10 2004 Andrew Cress <arcress@users.sourceforge.net> 
- added icmd utility to the rpm
* Thu Aug 05 2004 Andrew Cress <arcress@users.sourceforge.net> 
- added special logic for SuSE snmpd.conf
* Fri Apr 02 2004 Andrew Cress <arcress@users.sourceforge.net> 
- added checksel cron job
* Tue Jan 28 2003 Andrew Cress <arcress@users.sourceforge.net> 
- added sensor & fruconfig for ipmiutil 1.2.8
* Tue Aug  2 2002 Andrew Cress <arcress@users.sourceforge.net> 
- fixed bug 793 (dont need Require:ipmidrvr) for ipmiutil 1.2.2
* Tue Jul  2 2002 Andrew Cress <arcress@users.sourceforge.net> 
- fixed bug 555 in showsel for ipmiutil 1.2.1
* Fri May 10 2002 Andrew Cress <arcress@users.sourceforge.net> 
- fixed bug 504 in pefconfig for ipmiutil 1.1.5
* Thu Apr 11 2002 Andrew Cress <arcress@users.sourceforge.net> 
- updated pathnames for ipmiutil 1.1.4, some cleanup
* Mon Mar 18 2002 Andrew Cress <arcress@users.sourceforge.net> 
- updated for 1.1.3-2, added checking for grub vs. lilo to .spec
* Tue Mar 12 2002 Andrew Cress <arcress@users.sourceforge.net> 
- updated for 1.1.3, added source rpm, changed license, etc.
* Thu Jan 31 2002 Andrew Cress <arcress@users.sourceforge.net> 
- updated for 1.1.0-2, changed selpef to pefconfig
* Thu Jan 25 2002 Andrew Cress <arcress@users.sourceforge.net> 
- updated for 1.1.0, changed to ipmidrvr rather than isc dependency
* Thu Jan 16 2002 Andrew Cress <arcress@users.sourceforge.net> 
- updated for 1.1.0, added hwreset utility
* Thu Dec 14 2001 Andrew Cress <arcress@users.sourceforge.net> 
- updated for 1.0.0, man page updates
* Thu Nov 19 2001 Andrew Cress <arcress@users.sourceforge.net> 
- updated for 0.9.0, uses new OSS bmc_panic, so don't install module.
* Thu Nov 13 2001 Andrew Cress <arcress@users.sourceforge.net> 
- updated for 0.8.5, add "Requires: isc" (#32), hide selpef output (#38)
* Thu Nov  8 2001 Andrew Cress <arcress@users.sourceforge.net> 
- updated for 0.8.4, eliminate "file exists" messages by fixing removal
* Thu Oct 25 2001 Andrew Cress <arcress@users.sourceforge.net> 
- updated for 0.8.2, run selpef (objdump:applypatch gives bogus warning)
* Thu Oct 25 2001 Andrew Cress <arcress@users.sourceforge.net> 
- updated for 0.8.2, run selpef (objdump:applypatch gives bogus warning)
* Wed Oct 24 2001 Andrew Cress <arcress@users.sourceforge.net> 
- created ipmiutil package 0.8.1 without kbuild
* Tue Oct 23 2001 Andrew Cress <arcress@users.sourceforge.net> 
- created ipmiutil package 0.8.0
